<?php

namespace Drupal\doccheck_basic\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\user\Entity\User;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Drupal\doccheck_basic\DoccheckBasicCommon;

/**
 * DocCheck Basic Callback Controller.
 */
class CallbackController extends ControllerBase {

  /**
   * Doccheck callback page, redirects to requested URL.
   */
  public function callbackPage() {
    \Drupal::service('page_cache_kill_switch')->trigger();

    $config = \Drupal::config('config.doccheck_basic');

    $redirect_page = \Drupal::request()->getSession()->get('dc_page');
    \Drupal::request()->getSession()->remove('dc_page');

    if (strlen($redirect_page) == 0) {
      $err_msg = t("No cookie found. DocCheck Basic login cookie error.");
      return self::errorMsg($err_msg);
    }
    if (strlen($config->get('dc_user')) < 1) {
      $err_msg = t('DocCheck login user not set.');
      return self::errorMsg($err_msg);
    }
    if (\Drupal::currentUser()->id() == 0) {
      $dc_user = User::load($config->get('dc_user'));
      if ($dc_user === FALSE) {
        $err_msg = t('DocCheck login username not valid or not selected.');
        return self::errorMsg($err_msg);
      }
      if ($dc_user->hasRole('administrator')) {
        $err_msg = t('DocCheck login user has administrator role.');
        return self::errorMsg($err_msg);
      }
      user_login_finalize($dc_user);
    }

    $response = new RedirectResponse($redirect_page);
    $response->send();
    return $response;
  }

  /**
   * Defines login page.
   */
  public function loginPage() {
    return DoccheckBasicCommon::doccheckBasicLogin('page');
  }

  /**
   * Generate error message.
   */
  public function errorMsg($err_msg) {
    \Drupal::logger('doccheck_basic')->error($err_msg);
    drupal_set_message($err_msg, 'error');
    return [
      '#type' => 'markup',
      '#markup' => '',
      '#cache' => [
        'max-age' => 0,
      ],
    ];
  }

}
